@@ -228,7 +228,7 @@ class TestGetData:
     @pytest.mark.get_data
     def test_filters_by_field_id(self, good_object_id, get_three_good_field_ids, connector):
         connector.authenticate()
-        data = connector.get_data(good_object_id, get_three_good_field_ids)
+        data = connector.get_data(good_object_id, get_three_good_field_ids, n_rows=5)
         assert len(data["data"][0].keys()) == len(get_three_good_field_ids)
 
     @pytest.mark.source
@@ -297,7 +297,7 @@ class TestGetData:
                                   n_rows=5)
         start = datetime.strptime(custom_date_start_val, "%Y-%m-%d")
         end = datetime.strptime(custom_date_end_val, "%Y-%m-%d")
-        for row in data:
+        for row in data["data"]:
             assert start < datetime.strptime(data[row][filtered_column_nm], filtered_column_date_format)
             assert datetime.strptime(data[row][filtered_column_nm], filtered_column_date_format) < end
 
